@@ -185,6 +185,17 @@ class Main(QtWidgets.QMainWindow, Ui_MainWindow):
 
             start_navfile = timer()
             self.entry = navfile.load(file_path)
+            if not self.entry:
+                error_msg = 'Impossible to load the file.'
+                print(error_msg)
+
+                qw_msg = QtWidgets.QMessageBox()
+                qw_msg.setIcon(QtWidgets.QMessageBox.Critical)
+                qw_msg.setText(error_msg)
+                qw_msg.setWindowTitle("File Load Error")
+                qw_msg.exec_()
+
+                return None
             print('File loaded in =', timer()-start_navfile)
 
             # defining energies as of the gui
@@ -371,7 +382,7 @@ class Main(QtWidgets.QMainWindow, Ui_MainWindow):
                 os.path.dirname(file_path))
 
             self.exportDialog.kxbinsSpinBox.setValue(
-                len(self.entry.angles)*1.5)
+                int(len(self.entry.angles)*1.5))
             self.exportDialog.ksbinsSpinBox.setValue(
                 len(self.entry.scans)*5)
 
@@ -515,13 +526,9 @@ class Main(QtWidgets.QMainWindow, Ui_MainWindow):
             self
         """
         if self.file_loaded_flag:
-            self.axtop.lines.remove(self.isovmd_ln)
-            self.axtop.lines.remove(self.isovpd_ln)
             self.isovmd_ln = None
             self.isovpd_ln = None
-            self.axbot.lines.remove(self.scan_ln)
             self.scan_ln = None
-            self.axbot.lines.remove(self.angle_ln)
             self.angle_ln = None
 
             self.axtop.cla()
@@ -2011,7 +2018,7 @@ def main():
     form = Main()               # Set the form as Main
     form.show()                 # Show the form
 
-    sys.exit(app.exec_())
+    sys.exit(app.exec())
 
 
 if __name__ == '__main__':  # if running file directly and not importing it
