@@ -144,7 +144,7 @@ def align_to_same_eb(efermis, energies, data):
     energies_algn = np.copy(energies)
 
     delta_i_min = 0
-    delta_i_max = 0
+    delta_i_max = 1
 
     for i in range(energies.shape[0]):
         delta_i = (np.argmin(abs(en_ref-e_bins_all[i, :])) - i_ref)
@@ -160,10 +160,9 @@ def align_to_same_eb(efermis, energies, data):
                 delta_i_min = delta_i
 
     # reduce the size to eliminate border
-    delta_i_min = delta_i_min - 1
-    e_bins = e_bins[delta_i_max:delta_i_min]
-    energies_algn = energies_algn[:, delta_i_max:delta_i_min]
-    data_algn = data_algn[:, :, delta_i_max:delta_i_min]
+    e_bins = e_bins[-delta_i_min:-delta_i_max]
+    energies_algn = energies_algn[:, -delta_i_min:-delta_i_max]
+    data_algn = data_algn[:, :, -delta_i_min:-delta_i_max]
 
     return e_bins, energies_algn, data_algn
 
