@@ -45,8 +45,8 @@ class IsoScan:
         entry (NavEntry class): The class for the data explored by NavARP;
         scan (float): scan value;
         dscan (float): delta scan value;
-        norm_mode (string, optional, 'no' or 'all' or 'each'): if 'no', no
-            normalization; if 'each', every Slice are normalize by the
+        norm_mode (string, optional, default='no'): if 'no', no
+            normalization; if 'each', every Slice is normalized by the
             integral intensity of each Slice over their 90% of axis range;
             if "all", the overall z values are normalize to its min and
             max;
@@ -159,14 +159,21 @@ class IsoScan:
 
         return xax, yax, self.data, xname, yname
 
-    def dataprocessing(self, norm_mode, sigma, order, curvature, kbins):
+    def dataprocessing(
+        self,
+        norm_mode='no',
+        sigma=None,
+        order=2,
+        curvature=None,
+        kbins=None
+    ):
         """Apply data post-processing procedure.
 
         Args:
-            norm_mode (string, optional, 'no' or 'all' or 'each'): if 'no', no
-                normalization; if 'each', every Slice are normalize by the
+            norm_mode (string, optional, default='no'): if 'no', no
+                normalization; if 'each', every Slice is normalized by the
                 integral intensity of each Slice over their 90% of axis range;
-                if "all", the overall z values are normalize to its min and
+                if 'all', the overall z values are normalize to its min and
                 max;
             sigma (array, optional, default=None): Standard deviation for
                 Gaussian kernel. The standard deviations of the Gaussian filter
@@ -432,8 +439,8 @@ class IsoEnergy:
         entry (NavEntry class): The class for the data explored by NavARP;
         ebin (float): Binding energy value;
         debin (float): Delta binding energy value;
-        norm_mode (string, optional, 'no' or 'all' or 'each'): if 'no', no
-            normalization; if 'each', every Slice are normalize by the
+        norm_mode (string, optional, default='no'): if 'no', no
+            normalization; if 'each', every Slice is normalized by the
             integral intensity of each Slice over their 90% of axis range;
             if "all", the overall z values are normalize to its min and
             max;
@@ -501,14 +508,21 @@ class IsoEnergy:
 
         self.dataprocessing(norm_mode, sigma, order, curvature, kbins)
 
-    def dataprocessing(self, norm_mode, sigma, order, curvature, kbins):
+    def dataprocessing(
+        self,
+        norm_mode='no',
+        sigma=None,
+        order=2,
+        curvature=None,
+        kbins=None
+    ):
         """Apply data post-processing procedure.
 
         Args:
-            norm_mode (string, optional, 'no' or 'all' or 'each'): if 'no', no
-                normalization; if 'each', every Slice are normalize by the
+            norm_mode (string, optional, default='no'): if 'no', no
+                normalization; if 'each', every Slice is normalized by the
                 integral intensity of each Slice over their 90% of axis range;
-                if "all", the overall z values are normalize to its min and
+                if 'all', the overall z values are normalize to its min and
                 max;
             sigma (array, optional, default=None): Standard deviation for
                 Gaussian kernel. The standard deviations of the Gaussian filter
@@ -877,8 +891,8 @@ class IsoAngle:
         entry (NavEntry class): The class for the data explored by NavARP;
         angle (float): Angular value on the;
         dangle (float): Delta angular value;
-        norm_mode (string, optional, 'no' or 'all' or 'each'): if 'no', no
-            normalization; if 'each', every Slice are normalize by the
+        norm_mode (string, optional, default='no'): if 'no', no
+            normalization; if 'each', every Slice is normalized by the
             integral intensity of each Slice over their 90% of axis range;
             if "all", the overall z values are normalize to its min and
             max;
@@ -1013,14 +1027,20 @@ class IsoAngle:
         )
         return qmisoangle
 
-    def dataprocessing(self, norm_mode, sigma, order, curvature):
+    def dataprocessing(
+        self,
+        norm_mode='no',
+        sigma=None,
+        order=2,
+        curvature=None
+    ):
         """Use data post-processing procedure.
 
         Args:
-            norm_mode (string, optional, 'no' or 'all' or 'each'): if 'no', no
-                normalization; if 'each', every Slice are normalize by the
+            norm_mode (string, optional, default='no'): if 'no', no
+                normalization; if 'each', every Slice is normalized by the
                 integral intensity of each Slice over their 90% of axis range;
-                if "all", the overall z values are normalize to its min and
+                if 'all', the overall z values are normalize to its min and
                 max;
             sigma (array, optional, default=None): Standard deviation for
                 Gaussian kernel. The standard deviations of the Gaussian filter
@@ -1065,8 +1085,8 @@ class IsoK:
             interpolation function is going to be defined (the smaller the
             faster is the interpolation procedure), is generated once and used
             in all the ebins_interp range;
-        norm_mode (string, optional, 'no' or 'all' or 'each'): if 'no', no
-            normalization; if 'each', every Slice are normalize by the
+        norm_mode (string, optional, default='no'): if 'no', no
+            normalization; if 'each', every Slice is normalized by the
             integral intensity of each Slice over their 90% of axis range;
             if "all", the overall z values are normalize to its min and
             max;
@@ -1147,14 +1167,20 @@ class IsoK:
 
         self.dataprocessing(norm_mode, sigma, order, curvature)
 
-    def dataprocessing(self, norm_mode, sigma, order, curvature):
+    def dataprocessing(
+        self,
+        norm_mode='no',
+        sigma=None,
+        order=2,
+        curvature=None
+    ):
         """Use data post-processing procedure.
 
         Args:
-            norm_mode (string, optional, 'no' or 'all' or 'each'): if 'no', no
-                normalization; if 'each', every Slice are normalize by the
+            norm_mode (string, optional, default='no'): if 'no', no
+                normalization; if 'each', every Slice is normalized by the
                 integral intensity of each Slice over their 90% of axis range;
-                if "all", the overall z values are normalize to its min and
+                if 'all', the overall z values are normalize to its min and
                 max;
             sigma (array, optional, default=None): Standard deviation for
                 Gaussian kernel. The standard deviations of the Gaussian filter
