@@ -43,13 +43,20 @@ try:
 except ImportError:
     print("ImportError: navarp must be installed before using it.")
 
+igor2_error_msg = (
+    "WARNING: igor2 package not found. "
+    "It is not necessary but, if not present, "
+    "pxt and ibw files cannot be loaded.\n"
+    "To install it in your python enviroment do: \n"
+    "pip install igor2"
+)
 try:
-    import igor.igorpy as igor  # For opening pxt files
-    from igor import binarywave
+    from igor2.packed import load as loadpxp  # For opening pxt files
+    from igor2.binarywave import load as loadibw
+    pxt_ibw_opening_flag = True
 except ImportError:
-    print("WARNING: igor package not found. " +
-          "It is not necessary but, if present, "
-          "pxt and ibw files can be loaded.\n")
+    print(igor2_error_msg)
+    pxt_ibw_opening_flag = False
 
 
 def decode_h5py(string):
@@ -663,15 +670,18 @@ def load(file_path):
     The function loads entry from:
         * NXarpes file from LOREA/ALBA(ES) and I05/Diamond(GB);
         * HDF5 file from SXARPES-ADRESS/PSI(CH);
-        * NEXUS file from Antares/Soleil(FR);
+        * NEXUS file from Antares/Soleil(FR) (only deflector scan);
         * folder with txt-files from Cassiopee/Soleil(FR);
-        * krx or txt-files from MBS A1Soft program;
-        * zip- or txt-file from Scienta-Omicron SES program;
-        * sp2 file from Specs program;
-        * pxt, ibw, itx and txt file of Igor-pro as saved by Scienta-Omicron
-          SES program;
-        * yaml file with dictionary to load files (txt, sp2, pxt or ibw) in a
-          folder.
+        * krx or txt file from MBS A1Soft program;
+        * sp2 or itx file from SpecsLab Prodigy program;
+        * zip or txt file from Scienta-Omicron SES program;
+        * pxt, ibw and itx file of Igor-pro as saved by Scienta-Omicron SES
+          program;
+        * txt file in itx format of Igor-pro considering the order (energy,
+          angle, scan);
+        * yaml file with dictionary to load files (txt, sp2 or pxt) in a folder
+          or to only add metadata to a single file.
+
     The type of data is recognized from the file-extension:
         * *.nxs* is considered as NXarpes data if the first group is entry1
           otherwise a NEXUS file from Antares/Soleil(FR) if second group is
@@ -702,15 +712,15 @@ def load(file_path):
     """
     error_msg = (
         'Data format error.\n' +
-        'Unknown file structure, the only supported data are:\n' +
-        '   NXarpes file from LOREA/ALBA(ES) and I05/Diamond(GB);\n' +
-        '   HDF5 file from SXARPES-ADRESS/PSI(CH);\n' +
-        '   NEXUS file from Antares/Soleil(FR);\n' +
-        '   folder with txt-files from Cassiopee/Soleil(FR);\n' +
-        '   zip-, ibw-, pxt-, txt-files from Scienta-Omicron SES program;\n' +
-        '   krx- or txt-files from MBS A1Soft program;\n'
-        '   sp2 file from Specs program;\n'
-        '   itx-, txt-files from Igor-pro program.'
+        'Unknown file structure, the only supported data are:\n'
+        '   NXarpes file from LOREA/ALBA(ES) and I05/Diamond(GB);\n'
+        '   HDF5 file from SXARPES-ADRESS/PSI(CH);\n'
+        '   NEXUS file from Antares/Soleil(FR);\n'
+        '   folder with txt-files from Cassiopee/Soleil(FR);\n'
+        '   krx or txt file from MBS A1Soft program;\n'
+        '   sp2 or itx file from SpecsLab Prodigy program;\n'
+        '   zip, ibw, pxt, itx, txt files from Scienta-Omicron SES program;\n'
+        '   itx, txt files from Igor-pro in the order (energy, angle, scan).'
     )
 
     if '.h5' in file_path:
@@ -761,19 +771,15 @@ def load(file_path):
         else:
             print(error_msg)
 
-    elif '.pxt' in file_path:
-        entry = load_igorpro_pxt(file_path)
-        if entry:
-            return entry
+    elif ('.pxt' in file_path) or ('.ibw' in file_path):
+        if pxt_ibw_opening_flag:
+            entry = load_igorpro_pxt_ibw(file_path)
+            if entry:
+                return entry
+            else:
+                print(error_msg)
         else:
-            print(error_msg)
-
-    elif '.ibw' in file_path:
-        entry = load_igorpro_ibw(file_path)
-        if entry:
-            return entry
-        else:
-            print(error_msg)
+            print(igor2_error_msg)
 
     elif '.itx' in file_path:
         entry = load_igorpro_itx(file_path)
@@ -985,16 +991,21 @@ def load_nxarpes(h5f, file_path):
     data = np.zeros(h5f_data.shape, dtype='float32')
     h5f_data.read_direct(data)
 
+    # if data is 2D make as 3D with a single scan
+    if len(data.shape) == 2:
+        data = np.tile(data, (1, 1, 1))
+
     scan_type = None
     # scans and scan_type
     if data.shape[0] == 1:
         scan_type = "single"
         scans = np.array([0])
     else:
-        for key in ["polar", "tilt", "azimuth", "hv", "deflector"]:
+        for key in ["hv", "deflector", "tilt", "azimuth", "polar"]:
             if len(params[key]) == data.shape[0]:
                 scans = params[key]
                 scan_type = key
+                break
     if not scan_type:
         scans = np.arange(data.shape[0])
         scan_type = "unknown"
@@ -1175,19 +1186,40 @@ def load_nxsantares(h5f, file_path):
 
     # deflector angles
     defl_angles = h5f[fst_grp+"/scan_data/actuator_1_1"][()]
+    # check if deflector angles contains NaNs and in the case replace them
+    if np.isnan(defl_angles).any():
+        mask = np.isnan(defl_angles)
+        last_valid = defl_angles[np.invert(mask)][-1]
+        delta = np.round(last_valid - defl_angles[np.invert(mask)][-2], 6)
+        defl_angles[mask] = (
+            last_valid + (1 + np.arange(len(defl_angles[mask]))*delta))
 
     # scans and scan_type
     scans = defl_angles
     scan_type = "deflector"
 
-    hv = h5f[fst_grp+"/ANTARES/Monochromator/energy/data"][()]
-    en_res = h5f[fst_grp+"/ANTARES/Monochromator/resolution/data"][()]
+    # hv and energy resolution from monochromator
+    for key in h5f[fst_grp+"/ANTARES"]:
+        if key == r"Monochromator":
+            hv = h5f[fst_grp+"/ANTARES/Monochromator/energy/data"][()]
+            en_res = h5f[fst_grp+"/ANTARES/Monochromator/resolution/data"][()]
+            break
+        elif key == r"i12-m-c04-op-mono1":
+            hv = h5f[fst_grp+"/ANTARES/i12-m-c04-op-mono1/energy"][()]
+            en_res = h5f[fst_grp+"/ANTARES/i12-m-c04-op-mono1/resolution"][()]
+            break
+        # WARNING: can't find photon energy (hv), using default of 123
+        hv = np.array([123])
+        en_res = 0
 
     mbs_grp = [key for key in h5f[fst_grp+"/ANTARES"] if "MBSAcq" in key][0]
-    mode = h5f[fst_grp+"/ANTARES/"+mbs_grp+"/LensMode/data"][()]
-    epass = h5f[fst_grp+"/ANTARES/"+mbs_grp+"/PASSENERGY/data"][()]
-    mode = decode_h5py(mode)
-    epass = decode_h5py(epass)
+    mbs_grp = fst_grp + "/ANTARES/" + mbs_grp
+    params = {}
+    for key in h5f[mbs_grp]:
+        if isinstance(h5f[mbs_grp][key], h5py.Dataset):
+            params[key] = h5f[mbs_grp][key][()]
+        else:
+            params[key] = h5f[mbs_grp][key][r"data"][()]
 
     angle_min = h5f[fst_grp+"/scan_data/data_04"][()][0]
     angle_mult = h5f[fst_grp+"/scan_data/data_05"][()][0]
@@ -1228,11 +1260,10 @@ def load_nxsantares(h5f, file_path):
         "scan_type = {}\n".format(scan_type) +
         "sample = {}\n".format(fst_grp) +
         "hv = {}\n".format(hv_note) +
-        "en_res = {}\n".format(en_res[0]) +
-        "epass = {}\n".format(epass) +
-        "lens_mode = {}\n".format(mode) +
-        " deflector = scan along tilt"
+        "en_res = {}\n".format(en_res[0])
     )
+    for key in params:
+        file_note += "{} = {}\n".format(key, params[key])
 
     # closing h5f-file
     h5f.close()
@@ -1324,6 +1355,10 @@ def load_cassiopee(file_path):
             file_name[:re.search("ROI", file_name).start()] + "i.txt")
 
         info_file = os.path.join(info_file_dir, info_file_name)
+        if not os.path.isfile(info_file):
+            print("Error: no {} in the folder.".format(info_file))
+            print("Must be in the same directory of ROIs or in /info_files/")
+            return None
 
         with open(info_file) as fdat:
             for line in fdat:
@@ -1504,7 +1539,11 @@ def load_known_txt(file_path):
 
     if 'IGOR' in line:  # Igor itx format
         return load_igorpro_itx(file_path)
-    elif ('[Info]' in line) or ('Frames Per Step' in line):  # Scienta or MBS
+    elif (
+        ('[Info]' in line) or
+        ('Frames Per Step' in line) or
+        ('Lines' in line)
+    ):  # Scienta or MBS
         return load_scienta_or_mbs_txt(file_path)
     else:  # it is unknow
         return None
@@ -1527,7 +1566,10 @@ def load_scienta_or_mbs_txt(file_path):
             dataform = 'scienta'
             separator = '='
             breaking = '[Data 1'
-        elif 'Frames Per Step' in line:  # it is from MBS A1Soft
+        elif (
+            ('Frames Per Step' in line) or
+            ('Lines' in line)
+        ):  # it is from MBS A1Soft
             dataform = 'mbs'
             separator = '\t'
             breaking = 'DATA:'
@@ -1544,10 +1586,10 @@ def load_scienta_or_mbs_txt(file_path):
         if dataform == 'scienta':
             angles = np.array(
                 params["Dimension 2 scale"].replace(',', '.').split()
-            ).astype(np.float)
+            ).astype(float)
             energies = np.array(
                 params["Dimension 1 scale"].replace(',', '.').split()
-            ).astype(np.float)
+            ).astype(float)
             if 'Excitation Energy' in params:
                 hv = np.array([
                     float(params['Excitation Energy'].replace(',', '.'))])
@@ -1561,7 +1603,7 @@ def load_scienta_or_mbs_txt(file_path):
             if "Dimension 3 size" in params:
                 defl_angles = np.array(
                     params["Dimension 3 scale"].replace(',', '.').split()
-                ).astype(np.float)
+                ).astype(float)
 
                 # scans and scan_type
                 scan_type = 'deflector'
@@ -1593,11 +1635,18 @@ def load_scienta_or_mbs_txt(file_path):
                         break
 
         elif dataform == 'mbs':
-            angles = np.linspace(
-                float(params['XScaleMin']),
-                float(params['XScaleMax']),
-                int(params['NoS'])
-            )
+            if 'XScaleMin' in params:
+                angles = np.linspace(
+                    float(params['XScaleMin']),
+                    float(params['XScaleMax']),
+                    int(params['NoS'])
+                )
+            elif 'ScaleMin' in params:
+                angles = np.linspace(
+                    float(params['ScaleMin']),
+                    float(params['ScaleMax']),
+                    int(params['NoS'])
+                )
             energies = np.linspace(
                 float(params['Start K.E.']),
                 float(params['End K.E.']),
@@ -1785,17 +1834,23 @@ def load_mbs_krx(file_path):
                 int(len_scan)
             )
     else:
-        x_scale = np.linspace(
-            float(params['XScaleMin']),
-            float(params['XScaleMax']),
-            int(params['NoS'])
-        )
         if len_scan != 1:
             defl_angles = np.linspace(
                 float(params['YScaleMin']),
                 float(params['YScaleMax']),
                 int(len_scan)
             )
+            x_scale = np.linspace(
+                float(params['XScaleMin']),
+                float(params['XScaleMax']),
+                int(params['NoS'])
+            )
+        else:
+            x_scale = np.linspace(
+                float(params['ScaleMin']),
+                float(params['ScaleMax']),
+                int(params['NoS'])
+            )
 
     # reading all the images
     for i in range(len_scan):
@@ -1846,11 +1901,11 @@ def load_mbs_krx(file_path):
     )
 
 
-def load_igorpro_pxt(file_path):
-    """Load pxt-file of Igor-pro as saved from Scienta-Omicro SES program.
+def load_igorpro_pxt_ibw(file_path):
+    """Load Igor-pro pxt- or ibw-file as saved by Scienta-Omicro SES program.
 
     Args:
-        path: file path of the pxt-file.
+        path: file path of the pxt- or ibw-file.
 
     Returns:
         NavEntry (class): the class for the data to be explored by NavARP.
@@ -1859,68 +1914,10 @@ def load_igorpro_pxt(file_path):
     analyzer = NavAnalyzer(tht_ap=50, phi_ap=0, work_fun=4.5)
 
     # Load the pxt-file
-    pxt_file = igor.load(file_path)
-    pxt_file_folder = pxt_file.children[0]
-
-    angle_min = pxt_file_folder.axis[1][-1]
-    angle_step = pxt_file_folder.axis[1][0]
-    angle_len = pxt_file_folder.axis[1].shape[0]
-    angle_max = angle_min + (angle_len - 1)*angle_step
-    angles = np.linspace(angle_min, angle_max, angle_len)
-
-    energy_min = pxt_file_folder.axis[0][-1]
-    energy_step = pxt_file_folder.axis[0][0]
-    energy_len = pxt_file_folder.axis[0].shape[0]
-    energy_max = energy_min + (energy_len - 1)*energy_step
-    energies = np.linspace(energy_min, energy_max, energy_len)
-
-    data = np.transpose(pxt_file_folder.data)
-
-    data = np.tile(data, (1, 1, 1))
-
-    # extract meta data from '{}.ini'.format(region_name)
-    strings = pxt_file_folder.notes.decode("utf-8").split('\r')
-    params = {}
-    for string in strings:
-        if '=' in string:
-            string_split = string.split('=')
-            params[string_split[0]] = string_split[1]
-
-    if 'Excitation Energy' in params:
-        hv = np.array([float(params['Excitation Energy'].replace(',', '.'))])
-    else:
-        # WARNING: can't find photon energy (hv), using default value of 123
-        hv = np.array([123])
-
-    scans = np.array([1])
-
-    scan_type = 'single'
-
-    defl_angles = 0
-
-    file_note = "scan_type = {}\n".format(scan_type)
-    for key in params:
-        if "Dimension " not in key:
-            file_note += "{} = {}\n".format(key, params[key])
-
-    return NavEntry(scans, angles, energies, data, scan_type, hv, defl_angles,
-                    analyzer, file_note, file_path)
-
-
-def load_igorpro_ibw(file_path):
-    """Load ibw-file of Igor-pro as saved from Scienta-Omicro SES program.
-
-    Args:
-        path: file path of the ibw-file.
-
-    Returns:
-        NavEntry (class): the class for the data to be explored by NavARP.
-    """
-    # analyzer
-    analyzer = NavAnalyzer(tht_ap=50, phi_ap=0, work_fun=4.5)
-
-    # Load the pxt-file
-    ibw_file = binarywave.load(file_path)
+    if '.pxt' in file_path:
+        ibw_file = loadpxp(file_path)[0][0].wave
+    elif '.ibw' in file_path:
+        ibw_file = loadibw(file_path)
 
     energy_step, angle_step = ibw_file['wave']['wave_header']['sfA'][0:2]
     energy_min, angle_min = ibw_file['wave']['wave_header']['sfB'][0:2]
@@ -1974,66 +1971,127 @@ def load_igorpro_itx(file_path):
         NavEntry (class): the class for the data to be explored by NavARP.
     """
     file_note = ''
+    is_specslabprodigy = False
+    hv = np.array([123])
+    work_fun = 4.5
     with open(file_path) as fdat:
         fdat.readline()  # IGOR
-        ln_wave = fdat.readline()  # WAVES...
-        wave_name = ln_wave[ln_wave.find(')')+1:].strip()
-        ln_shape = ln_wave[ln_wave.find("(")+1:ln_wave.find(")")]
-        found_ints = np.fromstring(ln_shape, sep=',', dtype=int)
+        for line in fdat:
+            if "SpecsLab Prodigy" in line:
+                is_specslabprodigy = True
+            if "Excitation Energy" in line:
+                try:
+                    hv = np.array([float(line.split('=')[-1])])
+                except ValueError:
+                    print('No valid Excitation Energy.')
+            if "WorkFunction" in line:
+                try:
+                    work_fun = np.array([float(line.split('=')[-1])])
+                except ValueError:
+                    print('No valid WorkFunction.')
+            if "WAVES" in line:
+                # ln_wave = fdat.readline()  # WAVES...
+                wave_name = line[line.find(')')+1:].strip()
+                ln_shape = line[line.find("(")+1:line.find(")")]
+                found_ints = np.fromstring(ln_shape, sep=',', dtype=int)
+                break
+
+        if is_specslabprodigy:
+            energies_len = found_ints[1]
+            angles_len = found_ints[0]
+            # data have one value more than what declared in WAVE line
+            # this is an error in the file, and this is a patch to that
+            # error
+            angles_len += 1
+        else:
+            energies_len = found_ints[0]
+            angles_len = found_ints[1]
 
         if len(found_ints) == 2:
-            energies_len = found_ints[0]
-            angles_len = found_ints[1]
-            data = np.zeros((1, angles_len, energies_len), dtype='float32')
-            scans = np.array([1])
+            scans_len = 1
             scan_type = "single"
+            scans = np.array([1])
         elif len(found_ints) == 3:
-            energies_len = found_ints[0]
-            angles_len = found_ints[1]
             scans_len = found_ints[2]
-            data = np.zeros(
-                (scans_len, angles_len, energies_len), dtype='float32')
             scan_type = "unknown"
             scans = np.arange(scans_len)
 
+        data = np.zeros(
+            (scans_len, angles_len, energies_len), dtype='float32')
+
         fdat.readline()  # BEGIN
-        en_i = 0
+        first_i = 0  # energies or angles depending on is_specslabprodigy
+        if is_specslabprodigy:
+            first_len = angles_len
+        else:
+            first_len = energies_len
         scan_i = 0
         for line in fdat:
-            if "END" in line:
+            if 'END' in line:
                 break
             else:
-                data[scan_i, :, en_i] = np.fromstring(
-                    line, dtype=float, sep='\t')
-                en_i += 1
-                if en_i == energies_len:
-                    en_i = 0
+                if is_specslabprodigy:
+                    data[scan_i, first_i, :] = np.fromstring(
+                        line, dtype=float, sep='\t')
+                else:
+                    data[scan_i, :, first_i] = np.fromstring(
+                        line, dtype=float, sep='\t')
+                first_i += 1
+                if first_i == first_len:
+                    first_i = 0
                     scan_i += 1
+                    if scan_i == scans_len:
+                       break
+
+        if is_specslabprodigy:  # patch for consistency with igorpro
+            # the file has one additional pixel in angle
+            # which is not loaded in igor pro
+            # so for consistency the last pixel in angle must be removed
+            data = data[:, :-1, :]
+            angles_len -= 1
 
         # read last lines
         ln_axis = ''
         for line in fdat:
             ln_axis += line
         rege_float = r"[-+]?\d*\.?\d+"
-        matches = re.findall(
-            r'SetScale/P [x,y,z]\s*?[,\s]\s*{}\s*?[,\s]\s*{}'.format(
-                rege_float, rege_float), ln_axis)
-        for match in matches:
-            first_two_floats = re.findall(
-                r'{}\s*?[,\s]\s*{}'.format(rege_float, rege_float), match)[0]
-            start, delta = np.fromstring(first_two_floats, sep=',')
-            if match[11:12] == 'x':
-                end = start + (energies_len - 1)*delta
-                energies = np.linspace(start, end, energies_len)
-            elif match[11:12] == 'y':
-                end = start + (angles_len - 1)*delta
-                angles = np.linspace(start, end, angles_len)
-            elif match[11:12] == 'z':
-                if scans_len > 1:
-                    end = start + (scans_len - 1)*delta
-                    scans = np.linspace(start, end, scans_len)
-
-    hv = np.array([123])
+        if is_specslabprodigy:
+            matches = re.findall(
+                r'SetScale/I [x,y,z]\s*?[,\s]\s*{}\s*?[,\s]\s*{}'.format(
+                    rege_float, rege_float), ln_axis)
+            for match in matches:
+                first_two_floats = re.findall(
+                    r'{}\s*?[,\s]\s*{}'.format(rege_float, rege_float),
+                    match
+                )[0]
+                start, end = np.fromstring(first_two_floats, sep=',')
+                if match[11:12] == 'y':
+                    energies = np.linspace(start, end, energies_len)
+                elif match[11:12] == 'x':
+                    angles = np.linspace(start, end, angles_len)
+                elif match[11:12] == 'z':
+                    if scans_len > 1:
+                        scans = np.linspace(start, end, scans_len)
+        else:
+            matches = re.findall(
+                r'SetScale/P [x,y,z]\s*?[,\s]\s*{}\s*?[,\s]\s*{}'.format(
+                    rege_float, rege_float), ln_axis)
+            for match in matches:
+                first_two_floats = re.findall(
+                    r'{}\s*?[,\s]\s*{}'.format(rege_float, rege_float),
+                    match
+                )[0]
+                start, delta = np.fromstring(first_two_floats, sep=',')
+                if match[11:12] == 'x':
+                    end = start + (energies_len - 1)*delta
+                    energies = np.linspace(start, end, energies_len)
+                elif match[11:12] == 'y':
+                    end = start + (angles_len - 1)*delta
+                    angles = np.linspace(start, end, angles_len)
+                elif match[11:12] == 'z':
+                    if scans_len > 1:
+                        end = start + (scans_len - 1)*delta
+                        scans = np.linspace(start, end, scans_len)
 
     # look for notes on the wave
     params = {}
@@ -2064,7 +2122,7 @@ def load_igorpro_itx(file_path):
         scan_type,
         hv,
         defl_angles=0,
-        analyzer=NavAnalyzer(),
+        analyzer=NavAnalyzer(work_fun=work_fun),
         file_note=file_note,
         file_path=file_path,
     )
@@ -2170,10 +2228,29 @@ def load_navarp_yaml(file_path):
     else:
         # without checking the consistency, use as energies only the first one
         # since the kinetic energies cannot be different without a hv scan
-        entry_out.energies = entry_out.energies[0, :]
+        if len(entry_out.energies.shape) == 2:
+            entry_out.energies = entry_out.energies[0, :]
         if entry_out.scan_type == 'deflector':
             entry_out.defl_angles = entry_out.scans
 
+    # checking if energies scale is in binding energy and
+    # transforming to kinetic energies in the case
+    if 'energy_scale' in entry_info:
+        if 'bin' in entry_info['energy_scale'].lower():
+            if entry_out.scan_type == 'hv':
+                energies = (
+                    entry_out.hv[:, np.newaxis]
+                    - entry_out.analyzer.work_fun
+                    + entry_out.energies[np.newaxis, :]
+                )
+            else:
+                energies = (
+                    entry_out.hv
+                    - entry_out.analyzer.work_fun
+                    + entry_out.energies
+                )
+            entry_out.energies = energies
+
     entry_out.file_note = re.sub(
         "scan_type = [A-Za-z_]+",
         "scan_type = {}".format(entry_out.scan_type),
